cysignals: Interrupt and signal handling for Cython
===================================================

Description
-----------

Interrupt and signal handling for Cython

License
-------

LGPL version 3 or later


Upstream Contact
----------------

https://github.com/sagemath/cysignals

